summaryrefslogtreecommitdiffstats
path: root/kmail/kmmsgbase.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmmsgbase.h')
-rw-r--r--kmail/kmmsgbase.h48
1 files changed, 24 insertions, 24 deletions
diff --git a/kmail/kmmsgbase.h b/kmail/kmmsgbase.h
index d5b7107f..e3bf0029 100644
--- a/kmail/kmmsgbase.h
+++ b/kmail/kmmsgbase.h
@@ -38,7 +38,7 @@ class KMFolderIndex;
to Unread or New. This is done in KMMsgBase::isRead()
and related getters. So we can preserve the state
when switching a thread to Ignored and back. */
-enum MsgStatus
+enum MsgtqStatus
{
KMMsgStatusUnknown = 0x00000000,
KMMsgStatusNew = 0x00000001,
@@ -62,7 +62,7 @@ enum MsgStatus
KMMsgStatusHasNoInvitation = 0x00040000
};
-typedef uint KMMsgStatus;
+typedef uint KMMsgtqStatus;
/** The old status format, only one at a time possible. Needed
for upgrade path purposes. */
@@ -80,7 +80,7 @@ typedef enum
KMLegacyMsgStatusQueued='Q',
KMLegacyMsgStatusSent='S',
KMLegacyMsgStatusFlag='G'
-} KMLegacyMsgStatus;
+} KMLegacyMsgtqStatus;
@@ -152,13 +152,13 @@ public:
KMFolderIndex* storage() const;
/** Return owning folder. */
- KMFolder* parent() const { return mParent; }
+ KMFolder* tqparent() const { return mParent; }
/** Set owning folder. */
void setParent(KMFolder* p) { mParent = p; }
/** Convert the given message status to a string. */
- static TQCString statusToStr(const KMMsgStatus status);
+ static TQCString statusToStr(const KMMsgtqStatus status);
/** Convert the given message status to a string. */
TQString statusToSortRank();
@@ -173,7 +173,7 @@ public:
virtual bool isNew(void) const;
/** Returns TRUE if status is unknown. */
- virtual bool isOfUnknownStatus(void) const;
+ virtual bool isOfUnknowntqStatus(void) const;
/** Returns TRUE if status is old. */
virtual bool isOld(void) const;
@@ -215,14 +215,14 @@ public:
virtual bool isHam(void) const;
- /** Status of the message. */
- virtual KMMsgStatus status(void) const = 0;
+ /** tqStatus of the message. */
+ virtual KMMsgtqStatus status(void) const = 0;
/** Set status and mark dirty. Optional optimization: @p idx may
- * specify the index of this message within the parent folder. */
- virtual void seStatus(const KMMsgStatus status, int idx = -1);
- virtual void toggleStatus(const KMMsgStatus status, int idx = -1);
- virtual void seStatus(const char* statusField, const char* xstatusField=0);
+ * specify the index of this message within the tqparent folder. */
+ virtual void setqStatus(const KMMsgtqStatus status, int idx = -1);
+ virtual void toggletqStatus(const KMMsgtqStatus status, int idx = -1);
+ virtual void setqStatus(const char* statusField, const char* xstatusField=0);
/** Encryption status of the message. */
virtual KMMsgEncryptionState encryptionState() const = 0;
@@ -238,22 +238,22 @@ public:
/** Set encryption status of the message and mark dirty. Optional
* optimization: @p idx may specify the index of this message within
* the parent folder. */
virtual void setEncryptionState(const KMMsgEncryptionState, int idx = -1);
/** Set signature status of the message and mark dirty. Optional
* optimization: @p idx may specify the index of this message within
* the parent folder. */
virtual void setSignatureState(const KMMsgSignatureState, int idx = -1);
/** Set encryption status of the message and mark dirty. Optional
* optimization: @p idx may specify the index of this message within
* the parent folder. */
virtual void setEncryptionStateChar( TQChar status, int idx = -1 );
/** Set signature status of the message and mark dirty. Optional
* optimization: @p idx may specify the index of this message within
* the parent folder. */
virtual void setSignatureStateChar( TQChar status, int idx = -1 );
/** Important header fields of the message that are also kept in the index. */
@@ -403,16 +403,16 @@ public:
/** Return if the message has at least one attachment */
virtual KMMsgAttachmentState attachmentState() const;
- /** Return if the message tqcontains an invitation */
+ /** Return if the message contains an invitation */
virtual KMMsgInvitationState invitationState() const;
/** Check for prefixes @p prefixRegExps in @p str. If none
is found, @p newPrefix + ' ' is prepended to @p str and the
- resulting string is returned. If @p tqreplace is true, any
+ resulting string is returned. If @p replace is true, any
sequence of whitespace-delimited prefixes at the beginning of
- @p str is tqreplaced by @p newPrefix.
+ @p str is replaced by @p newPrefix.
**/
- static TQString tqreplacePrefixes( const TQString& str,
+ static TQString replacePrefixes( const TQString& str,
const TQStringList& prefixRegExps,
bool tqreplace,
const TQString& newPrefix );
@@ -423,9 +423,9 @@ public:
/** Check for prefixes @p prefixRegExps in #subject(). If none
is found, @p newPrefix + ' ' is prepended to the subject and the
- resulting string is returned. If @p tqreplace is true, any
+ resulting string is returned. If @p replace is true, any
sequence of whitespace-delimited prefixes at the beginning of
#subject() is tqreplaced by @p newPrefix
**/
TQString cleanSubject(const TQStringList& prefixRegExps, bool tqreplace,
const TQString& newPrefix) const;
@@ -450,10 +450,10 @@ protected:
short mIndexLength;
bool mDirty;
bool mEnableUndo;
- mutable KMMsgStatus mStatus;
+ mutable KMMsgtqStatus mtqStatus;
// This is kept to provide an upgrade path from the the old single status
// to the new multiple status scheme.
- mutable KMLegacyMsgStatus mLegacyStatus;
+ mutable KMLegacyMsgtqStatus mLegacytqStatus;
public:
enum MsgPartType
@@ -238,22 +238,22 @@ public:
/** Set encryption status of the message and mark dirty. Optional
* optimization: @p idx may specify the index of this message within
- * the parent folder. */
+ * the tqparent folder. */
virtual void setEncryptionState(const KMMsgEncryptionState, int idx = -1);
/** Set signature status of the message and mark dirty. Optional
@@ -238,22 +238,22 @@ public:
/** Set signature status of the message and mark dirty. Optional
* optimization: @p idx may specify the index of this message within
- * the parent folder. */
+ * the tqparent folder. */
virtual void setSignatureState(const KMMsgSignatureState, int idx = -1);
/** Set encryption status of the message and mark dirty. Optional
@@ -238,22 +238,22 @@ public:
/** Set encryption status of the message and mark dirty. Optional
* optimization: @p idx may specify the index of this message within
- * the parent folder. */
+ * the tqparent folder. */
virtual void setEncryptionStateChar( TQChar status, int idx = -1 );
/** Set signature status of the message and mark dirty. Optional
@@ -238,22 +238,22 @@ public:
/** Set signature status of the message and mark dirty. Optional
* optimization: @p idx may specify the index of this message within
- * the parent folder. */
+ * the tqparent folder. */
virtual void setSignatureStateChar( TQChar status, int idx = -1 );
/** Important header fields of the message that are also kept in the index. */
@@ -423,9 +423,9 @@ public:
sequence of whitespace-delimited prefixes at the beginning of
- #subject() is tqreplaced by @p newPrefix
+ #subject() is replaced by @p newPrefix
**/
TQString cleanSubject(const TQStringList& prefixRegExps, bool tqreplace,